@@ -8,6 +8,7 @@ import logging
 
 from django.core.management.base import BaseCommand
 from django.db import connection, ProgrammingError
+from django.db.backends.utils import truncate_name
 from django.apps import apps
 
 logger = logging.getLogger(__name__)
@@ -15,21 +16,21 @@ logger = logging.getLogger(__name__)
 
 class Command(BaseCommand):
     help = (
-        'Renames a Django Application. Usage rename_app [old_name] [new_name]'
+        'Renames a Django Application. Usage rename_app [old_app_name] [new_app_name]'
     )
 
     def add_arguments(self, parser):
-        parser.add_argument('old_name', nargs=1, type=str)
-        parser.add_argument('new_name', nargs=1, type=str)
+        parser.add_argument('old_app_name', nargs=1, type=str)
+        parser.add_argument('new_app_name', nargs=1, type=str)
 
-    def handle(self, old_name, new_name, *args, **options):
+    def handle(self, old_app_name, new_app_name, *args, **options):
         with connection.cursor() as cursor:
-            old_name = old_name[0]
-            new_name = new_name[0]
+            old_app_name = old_app_name[0]
+            new_app_name = new_app_name[0]
 
             cursor.execute(
                 "SELECT * FROM django_content_type "
-                f"where app_label='{new_name}'"
+                f"where app_label='{new_app_name}'"
             )
             has_already_been_ran = cursor.fetchone()
             if has_already_been_ran:
@@ -40,19 +41,28 @@ class Command(BaseCommand):
                 return None
 
             cursor.execute(
-                f"UPDATE django_content_type SET app_label='{new_name}' "
-                f"WHERE app_label='{old_name}'"
+                f"UPDATE django_content_type SET app_label='{new_app_name}' "
+                f"WHERE app_label='{old_app_name}'"
             )
             cursor.execute(
-                f"UPDATE django_migrations SET app='{new_name}' "
-                f"WHERE app='{old_name}'"
+                f"UPDATE django_migrations SET app='{new_app_name}' "
+                f"WHERE app='{old_app_name}'"
             )
-            models = apps.all_models[new_name]
-            models.update(apps.all_models[old_name])
+            models = apps.all_models[new_app_name]
+            models.update(apps.all_models[old_app_name])
             for model_name in models:
+                old_table_name = truncate_name(
+                    f"{old_app_name}_{model_name}",
+                    connection.ops.max_name_length()
+                )
+                new_table_name = truncate_name(
+                    f"{new_app_name}_{model_name}",
+                    connection.ops.max_name_length()
+                )
+
                 query = (
-                    f"ALTER TABLE {old_name}_{model_name} "
-                    f"RENAME TO {new_name}_{model_name}"
+                    f"ALTER TABLE {old_table_name} "
+                    f"RENAME TO {new_table_name}"
                 )
                 try:
                     cursor.execute(query)
